// Gmsh project created on Sat Apr 05 20:34:58 2014

// Dimensions of the machine
DefineConstant[ R_rot_in = { 23}];
DefineConstant[ R_rot_out = { 45}];
DefineConstant[ R_stat_out = { 93}];
DefineConstant[ Gap = { 0.6}];
DefineConstant[ b_d = { 20}];
DefineConstant[ hss_tot = { 34}];
DefineConstant[ bridge = { 0.5}];
DefineConstant[ w_PM = { 44}];
DefineConstant[ h_PM = { 5}];


// Mesh density points
DefineConstant[ mesh_gap = { Gap/4}];
DefineConstant[ mesh_fine = { 0.5}];
DefineConstant[ mesh_normal = { 3}];
DefineConstant[ mesh_coarse = { 6}];


//=================================================================
// Geometry definition

Point(1) = {0, 0, 0, mesh_coarse};

// ==========================================================
// =============== Stator Geometry ===============================
// ==========================================================

//Tooth bottom
Point(2) = {Gap+R_rot_out, 0, 0, mesh_gap};
Rotate {{0, 0, 1}, {0, 0, 0}, Asin(b_d/2/(Gap+R_rot_out))} {
  Duplicata { Point{2}; }
}
Rotate {{0, 0, 1}, {0, 0, 0}, -Asin(b_d/2/(Gap+R_rot_out))} {
  Duplicata { Point{2}; }
}

//Tooth top

Point(5) = {Gap+R_rot_out+hss_tot, 0, 0, mesh_normal};
Rotate {{0, 0, 1}, {0, 0, 0}, Asin(b_d/2/(Gap+R_rot_out+hss_tot))} {
  Duplicata { Point{5}; }
}
Rotate {{0, 0, 1}, {0, 0, 0}, -Asin(b_d/2/(Gap+R_rot_out+hss_tot))} {
  Duplicata { Point{5}; }
}

//Coil edges
Rotate {{0, 0, 1}, {0, 0, 0}, Pi/6} {
  Duplicata { Point{2, 5}; }
}
Rotate {{0, 0, 1}, {0, 0, 0}, -Pi/6} {
  Duplicata { Point{2, 5}; }
}

Circle(1) = {10, 1, 4};
Circle(2) = {4, 1, 2};
Circle(3) = {2, 1, 3};
Circle(4) = {3, 1, 8};
Circle(5) = {11, 1, 7};
Circle(6) = {6, 1, 9};
Line(7) = {11, 10};
Line(8) = {7, 4};
Line(9) = {6, 3};
Line(10) = {8, 9};

//Finalize stator yoke segment
Point(12) = {R_stat_out, 0, 0, mesh_coarse};
Rotate {{0, 0, 1}, {0, 0, 0}, -Pi/6} {
  Duplicata { Point{12}; }
}
Rotate {{0, 0, 1}, {0, 0, 0}, Pi/6} {
  Duplicata { Point{12}; }
}
Circle(11) = {13, 1, 12};
Circle(12) = {12, 1, 14};
outer_edges[] = {11, 12};

Line(13) = {14, 9};
Line(14) = {13, 11};

//Define plane surface steel segment
Line Loop(15) = {9, -3, -2, -8, -5, -14, 11, 12, 13, -6};
Plane Surface(16) = {15};

//Define plane surfaces of the coil (plus and minus of the phase coil)
Line Loop(17) = {10, -6, 9, 4};
Plane Surface(18) = {17};
Line Loop(19) = {8, -1, -7, 5};
Plane Surface(20) = {19};



//Complete stator geometry by duplicating the coil segment
Rotate {{0, 0, 1}, {0, 0, 0}, Pi/3} {
  Duplicata { Surface{16, 18, 20}; }
}
Rotate {{0, 0, 1}, {0, 0, 0}, Pi/3} {
  Duplicata { Surface{37, 21, 32}; }
}
Rotate {{0, 0, 1}, {0, 0, 0}, Pi/3} {
  Duplicata { Surface{40, 45, 56}; }
}
Rotate {{0, 0, 1}, {0, 0, 0}, Pi/3} {
  Duplicata { Surface{61, 66, 77}; }
}
Rotate {{0, 0, 1}, {0, 0, 0}, Pi/3} {
  Duplicata { Surface{82, 87, 98}; }
}


//Create sliding line in the middle of the airgap
Point(305) = {Gap/2+R_rot_out, 0, 0, mesh_gap};
Point(306) = {0, Gap/2+R_rot_out, 0, mesh_gap};
Point(307) = {-Gap/2-R_rot_out, 0, 0, mesh_gap};
Point(308) = {0, -Gap/2-R_rot_out, 0, mesh_gap};

Circle(124) = {305, 1, 306};
Circle(125) = {306, 1, 307};
Circle(126) = {307, 1, 308};
Circle(127) = {308, 1, 305};

//create air gap part of the stator
Line Loop(128) = {3, 4, -39, -24, -23, 36, -42, -48, -47, 60, -63, -69, -68, 81, -84, -90, -89, 102, -105, -111, -110, 123, 1, 2};
Line Loop(129) = {124, 125, 126, 127};
Plane Surface(130) = {128, 129};


// ==========================================================
// =============== Rotor geometry ===============================
// ==========================================================


//create rotor segment
Point(309) = {R_rot_in, 0, 0, mesh_coarse};
Point(310) = {R_rot_out, 0, 0, mesh_gap};

//Rotor geometry
Rotate {{0, 0, 1}, {0, 0, 0}, Pi/4} {
  Duplicata { Point{309, 310}; }
}
//Rotor geometry
Rotate {{0, 0, 1}, {0, 0, 0}, -Pi/4} {
  Duplicata { Point{309, 310}; }
}

//Outer and inner arcs of the pole sector
Circle(131) = {314, 1, 310};
Circle(132) = {310, 1, 312};
Circle(133) = {313, 1, 309};
Circle(134) = {309, 1, 311};

//Pole sector borders
Line(135) = {313, 314};
Line(136) = {312, 311};


//Magnet points
Point(315) = {(R_rot_out-bridge)*Cos(Asin(w_PM/2/(R_rot_out-bridge))), 0, 0, mesh_normal};
Point(316) = {(R_rot_out-bridge)*Cos(Asin(w_PM/2/(R_rot_out-bridge))), w_PM/2, 0, mesh_gap};
Point(317) = {(R_rot_out-bridge)*Cos(Asin(w_PM/2/(R_rot_out-bridge))), -w_PM/2, 0, mesh_gap};
Point(318) = {(R_rot_out-bridge)*Cos(Asin(w_PM/2/(R_rot_out-bridge)))-h_PM, 0, 0, mesh_normal};
Point(319) = {(R_rot_out-bridge)*Cos(Asin(w_PM/2/(R_rot_out-bridge)))-h_PM, w_PM/2, 0, mesh_normal};
Point(320) = {(R_rot_out-bridge)*Cos(Asin(w_PM/2/(R_rot_out-bridge)))-h_PM, -w_PM/2, 0, mesh_normal};

//Magnet lines
Line(137) = {316, 319};
Line(138) = {319, 318};
Line(139) = {318, 320};
Line(140) = {320, 317};
Line(141) = {317, 315};
Line(142) = {315, 316};

//PM surface
Line Loop(143) = {142, 137, 138, 139, 140, 141};
Plane Surface(144) = {143};


//Pole sector iron
Line Loop(145) = {131, 132, 136, -134, -133, 135};
Plane Surface(146) = {145, 143};

//Duplicate rotor poles
For it In {1:3}
	Rotate {{0, 0, 1}, {0, 0, 0}, it*Pi/2} {
  	  Duplicata { Surface{146, 144}; }
	}
EndFor


//Plane surface of the rotor airgap
Line Loop(189) = {132, 148, 149, 162, 163, 176, 177, 131};
Plane Surface(190) = {129, 189};

//Inner air surface
Line Loop(191) = {134, -152, -151, -166, -165, -180, -179, 133};
Plane Surface(192) = {191};

// ==========================================================
// =============== Bodies ===============================
// ==========================================================

//Stator iron
Physical Surface(1) = {21, 45, 66, 87, 108, 16};

//Rotor iron
Physical Surface(2) = {147, 161, 175, 146};

// u+-
Physical Surface(3) = {40, 103};
Physical Surface(4) = {56, 119};

// v+-
Physical Surface(5) = {20, 61};
Physical Surface(6) = {18, 77};

// w +-
Physical Surface(7) = {37, 82};
Physical Surface(8) = {32, 98};


// Airgap stator
Physical Surface(9) = {130};

// Airgap rotor
Physical Surface(10) = {190};

// PM1-4
Physical Surface(11) = {144};
Physical Surface(12) = {160};
Physical Surface(13) = {174};
Physical Surface(14) = {188};

// rotor shaft
Physical Surface(15) = {192};

// ==========================================================
// =============== Boundaries ===============================
// ==========================================================

//outer boundary
Physical Line(1) = {12, 28, 29, 52, 53, 73, 74, 94, 95, 115, 116, 11};

//sliding surface
Physical Line(2) = {127, 124, 125, 126};
